==> contacts-2.1.0.tar.gz: contacts/src/Form/AddContactForm.php <==
<?php

namespace Drupal\contacts\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Entity\EntityConstraintViolationListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\profile\Plugin\Field\FieldWidget\ProfileFormWidget;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form class used for the Add Contact screen.
 *
 * Used by the 'add_contact_individual' and 'add_contact_organisation'
 * form modes on the User entity.
 */
class AddContactForm extends ContentEntityForm {

  /**
   * Theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeManager
   */
  protected $themeManager;

  /**
   * User to create.
   *
   * @var \Drupal\user\Entity\User
   */
  protected $entity;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $self = parent::create($container);
    $self->themeManager = $container->get('theme.manager');
    return $self;
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    if ($this->themeManager->getActiveTheme()->getName() === 'contacts_theme') {
      // The contacts theme doesn't display status messages by default
      // (it only includes them on certain pages on the contacts
      // dashboard), so we need to explicitly render status messages if we're
      // inside the contacts theme.
      $form['status_messages'] = [
        '#type' => 'status_messages',
        '#weight' => -10,
      ];

      // If we're rendering the individual address or organisation address
      // swap out the default Details element for just a regular div so it
      // renders correctly in the contacts theme.
      if (isset($form['crm_indiv_profiles']['widget'][0]['entity']['crm_address']['widget'][0])) {
        $form['crm_indiv_profiles']['widget'][0]['entity']['crm_address']['widget'][0]['#type'] = 'container';
      }
      if (isset($form['crm_org_profiles']['widget'][0]['entity']['crm_org_address']['widget'][0])) {
        $form['crm_org_profiles']['widget'][0]['entity']['crm_org_address']['widget'][0]['#type'] = 'container';
      }
    }

    // If the pseudo mail field is configured to display, define it.
    if ($mail_component = $this->getFormDisplay($form_state)->getComponent('mail')) {
      $form['mail'] = [
        '#type' => 'email',
        '#title' => $this->t('Email address'),
        // Only required if we're adding an individual. Not required for org.
        '#required' => $this->getOperation() === 'add_contact_individual',
        '#weight' => $mail_component['weight'],
      ];
    }

    // Change the org profile fields from a collapsible details block
    // to a regular container.
    if (isset($form['crm_org_profiles']['widget'][0])) {
      $form['crm_org_profiles']['widget'][0]['#type'] = 'container';

      // Org name should be required.
      if (isset($form['crm_org_profiles']['widget'][0]['entity']['crm_org_name'])) {
        $form['crm_org_profiles']['widget'][0]['entity']['crm_org_name']['widget'][0]['value']['#required'] = TRUE;
      }
    }

    // Change the individual profile fields from a collapsible details block
    // to a regular container.
    if (isset($form['crm_indiv_profiles']['widget'][0])) {
      $form['crm_indiv_profiles']['widget'][0]['#type'] = 'container';

      // Name should be required.
      if (isset($form['crm_indiv_profiles']['widget'][0]['entity']['crm_name'])) {
        $form['crm_indiv_profiles']['widget'][0]['entity']['crm_name']['widget'][0]['#required'] = TRUE;
        $form['crm_indiv_profiles']['widget'][0]['entity']['crm_name']['widget'][0]['#show_component_required_marker'] = TRUE;
      }
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);

    // Add handler for 'save and add another'.
    $submit_handlers = $actions['submit']['#submit'];
    $submit_handlers[] = [ProfileFormWidget::class, 'saveProfiles'];
    $submit_handlers[] = '::addAnother';

    $actions['submit_and_add_another'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save and add another'),
      '#button_type' => 'primary',
      '#submit' => $submit_handlers,
    ];

    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    if ($this->getOperation() === 'add_contact_individual') {
      $this->entity->addRole('crm_indiv');
    }
    elseif ($this->getOperation() === 'add_contact_organisation') {
      $this->entity->addRole('crm_org');
    }

    // Saving the user will attempt to save the profiles too, which will
    // associate the new profile with the *current user* rather than the
    // *newly created user*. ProfileFormWidget::saveProfiles then corrects
    // this, but because Decoupled Auth has hooks for handling profile inserts
    // it will have already associated the profile with the current user's
    // auto-profile fields. To resolve this, unset the profiles from
    // the new user to ensure we do NOT do an initial save of the profile.
    // The profile will then only be saved as part of
    // ProfileFormWidget::saveProfiles.
    $this->entity->set('crm_indiv_profiles', NULL);
    $this->entity->set('crm_org_profiles', NULL);

    parent::save($form, $form_state);

    $this->messenger()->addStatus($this->t('Changes have been saved.'));

    $form_state->setRedirect('contacts.contact', [
      'user' => $this->entity->id(),
    ]);
  }

  /**
   * Submit handler when 'Save & Add Another' is clicked.
   *
   * @param array $form
   *   Form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   State.
   */
  public function addAnother(array &$form, FormStateInterface $form_state) {
    // Redirect back to self.
    $form_state->setRedirect(\Drupal::routeMatch()->getRouteName());
  }

  /**
   * {@inheritdoc}
   */
  protected function flagViolations(EntityConstraintViolationListInterface $violations, array $form, FormStateInterface $form_state) {
    parent::flagViolations($violations, $form, $form_state);

    // Special handling is required for the mail field. Usually the base class
    // will delegate handling of entity field validation errors to the
    // corresponding form widget, but in the case of 'mail' this is not defined
    // as a widget on the page, but rather as a pseudo field which we manually
    // build the text box for. As such, its violations won't be handled
    // automatically.
    foreach ($violations->getByField('mail') as $violation) {
      /** @var \Symfony\Component\Validator\ConstraintViolation $violation */
      $form_state->setError($form['mail'], $violation->getMessage());
    }
  }

}

==> contacts-3.1.2.tar.gz: contacts/src/Form/AddContactForm.php <==
<?php

namespace Drupal\contacts\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\profile\Plugin\Field\FieldWidget\ProfileFormWidget;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form class used for the Add Contact screen.
 *
 * Used by the 'add_contact' form mode on the Profile entity.
 */
class AddContactForm extends ContactsProfileForm {

  /**
   * Theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeManager
   */
  protected $themeManager;

  /**
   * Profile to create.
   *
   * @var \Drupal\profile\Entity\Profile
   */
  protected $entity;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $self = parent::create($container);
    $self->themeManager = $container->get('theme.manager');
    return $self;
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    if ($this->themeManager->getActiveTheme()->getName() === 'contacts_theme') {
      // The contacts theme doesn't display status messages by default
      // (it only includes them on certain pages on the contacts
      // dashboard), so we need to explicitly render status messages if we're
      // inside the contacts theme.
      $form['status_messages'] = [
        '#type' => 'status_messages',
        '#weight' => -10,
      ];
    }

    // If we're creating an organisation, org name should be required.
    if (isset($form['crm_org_name'])) {
      $form['crm_org_name']['widget'][0]['value']['#required'] = TRUE;
    }

    // If we're creating a person, name should be required.
    if (isset($form['crm_name'])) {
      $form['crm_name']['widget'][0]['#required'] = TRUE;
      $form['crm_name']['widget'][0]['#show_component_required_marker'] = TRUE;
    }

    // Note the contacts_mail pseudo/surrogate field is injected
    // into all profile forms including this one if it's configured in the
    // form mode. See Drupal\contacts\PseudoEmailField::alterProfileForm.
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);

    // Remove the Cancel action added by the ContactsProfileForm.
    unset($actions['cancel']);

    // Add handler for 'save and add another'.
    $submit_handlers = $actions['submit']['#submit'];
    $submit_handlers[] = [ProfileFormWidget::class, 'saveProfiles'];
    $submit_handlers[] = '::addAnother';

    $actions['submit_and_add_another'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save and add another'),
      '#button_type' => 'primary',
      '#submit' => $submit_handlers,
    ];

    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    parent::save($form, $form_state);

    $form_state->setRedirect('contacts.contact', [
      'user' => $this->entity->getOwnerId(),
    ]);
  }

  /**
   * Submit handler when 'Save & Add Another' is clicked.
   *
   * @param array $form
   *   Form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   State.
   */
  public function addAnother(array &$form, FormStateInterface $form_state) {
    // Redirect back to self.
    $form_state->setRedirect(\Drupal::routeMatch()->getRouteName());
  }

}
